@@ -1,6 +1,25 @@
-/*
- * rxvttoolkit.h - provide toolkit-functionality for rxvt.
- */
+/*----------------------------------------------------------------------*
+ * File:	rxvttoolkit.h - provide toolkit-functionality for rxvt.
+ *----------------------------------------------------------------------*
+ *
+ * All portions of code are copyright by their respective author/s.
+ * Copyright (c) 2003-2006 Marc Lehmann <pcg@goof.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *----------------------------------------------------------------------*/
+
 #ifndef RXVT_TOOLKIT_H
 #define RXVT_TOOLKIT_H
 
@@ -107,6 +126,33 @@ struct refcache : vector<T *> {
 
 /////////////////////////////////////////////////////////////////////////////
 
+struct rxvt_screen;
+
+struct rxvt_drawable {
+  rxvt_screen *screen;
+  Drawable drawable;
+  operator Drawable() { return drawable; }
+
+#if XFT
+  XftDraw *xftdrawable;
+  operator XftDraw *();
+#endif
+
+  rxvt_drawable (rxvt_screen *screen, Drawable drawable)
+  : screen(screen),
+#if XFT
+    xftdrawable(0),
+#endif
+    drawable(drawable)
+  { }
+
+#if XFT
+  ~rxvt_drawable ();
+#endif
+};
+
+/////////////////////////////////////////////////////////////////////////////
+
 #ifdef USE_XIM
 struct rxvt_xim : refcounted {
   void destroy ();
@@ -128,6 +174,16 @@ struct rxvt_screen {
   Visual *visual;
   Colormap cmap;
 
+#if XFT
+  // scratch pixmap
+  rxvt_drawable *scratch_area;
+  int scratch_w, scratch_h;
+
+  rxvt_drawable &scratch_drawable (int w, int h);
+
+  rxvt_screen ();
+#endif
+
   void set (rxvt_display *disp);
   void set (rxvt_display *disp, int bitdepth);
   void clear ();
@@ -152,9 +208,7 @@ struct rxvt_display : refcounted {
   Window    root;
   rxvt_term *selection_owner;
   Atom      xa[NUM_XA];
-#ifndef NO_SLOW_LINK_SUPPORT
   bool      is_local;
-#endif
 #ifdef POINTER_BLANK
   Cursor    blank_cursor;
 #endif
