@@ -155,8 +155,8 @@ selection.
 
 =item readline (enabled by default)
 
-A support package that tries to make editing with readline easier. At the
-moment, it reacts to clicking with the left mouse button by trying to
+A support package that tries to make editing with readline easier. At
+the moment, it reacts to clicking shift-left mouse button by trying to
 move the text cursor to this position. It does so by generating as many
 cursor-left or cursor-right keypresses as required (the this only works
 for programs that correctly support wide characters).
@@ -555,6 +555,12 @@ resource in the @@RXVT_NAME@@(1) manpage).
 The event is simply the action string. This interface is assumed to change
 slightly in the future.
 
+=item on_resize_all_windows $tern, $new_width, $new_height
+
+Called just after the new window size has been calculcated, but before
+windows are actually being resized or hints are being set. If this hook
+returns TRUE, setting of the window hints is being skipped.
+
 =item on_x_event $term, $event
 
 Called on every X event received on the vt window (and possibly other
@@ -1470,14 +1476,19 @@ Returns the LC_CTYPE category string used by this rxvt-unicode.
 Returns a copy of the environment in effect for the terminal as a hashref
 similar to C<\%ENV>.
 
+=item @envv = $term->envv
+
+Returns the environment as array of strings of the form C<VAR=VALUE>.
+
+=item @argv = $term->argv
+
+Return the argument vector as this terminal, similar to @ARGV, but
+includes the program name as first element.
+
 =cut
 
 sub env {
-   if (my $env = $_[0]->_env) {
-      +{ map /^([^=]+)(?:=(.*))?$/s && ($1 => $2), @$env }
-   } else {
-      +{ %ENV }
-   }
+   +{ map /^([^=]+)(?:=(.*))?$/s && ($1 => $2), $_[0]->envv }
 }
 
 =item $modifiermask = $term->ModLevel3Mask
